@@ -492,6 +492,41 @@ sub prepare_c_tests {
     }
 }
 
+sub todo_tests_default {
+    my $what = shift;
+    my $DEBUGGING = ($Config{ccflags} =~ m/-DDEBUGGING/);
+    my $ITHREADS  = ($Config{useithreads});
+
+    my @todo  = (39); # 8,14-16 fail on 5.00505 (max 20 then)
+    if ($what =~ /^c(|_o[1-4])/) {
+        @todo     = (27,39)    if !$ITHREADS;
+        # 14+23 fixed with 1.04_29, for 5.10 with 1.04_31
+        # 15+28 fixed with 1.04_34
+        # 5.6.2 CORE: 8,15,16,22. 16 fixed with 1.04_24, 8 with 1.04_25
+        # 5.8.8 CORE: 11,14,15,20,23 / non-threaded: 5,7-12,14-20,22-23,25
+        @todo = (15,27,41..44) if $] < 5.007;
+        # on cygwin 29 passes
+        @todo = (29,39,41)     if $] >= 5.010;
+        @todo = (15,39)        if $] >= 5.010 and !$ITHREADS;
+        if ($what eq 'c_o4') {
+            push @todo, (10,12,19,25);
+        }
+    } elsif ($what =~ /^cc/) {
+        # 8,11,14..16,18..19 fail on 5.00505 + 5.6, old core failures (max 20)
+        # on cygwin 29 passes
+        my @todo = (18,21,25,27,29,30,39); #5.8.9
+        push @todo, (15,41..44)           if $] < 5.007;
+        @todo    = (18,21,25,29,30,39,41) if $] >= 5.010;
+        @todo    = (10,16,18,21,25,29,30,39,41) if $] >= 5.010 and $what eq 'cc_o2';
+        # solaris and debian also. I suspect nvx<=>cop_seq_*
+        push @todo, (12) if $^O eq 'MSWin32' and $Config{cc} =~ /^cl/i;
+
+        push @todo, (26) if $what =~ /^cc_o[12]/;
+    }
+    push @todo, (32)   if $] >= 5.011003;
+    return @todo;
+}
+
 sub run_c_tests {
     my $backend = $_[0];
     my @todo = @{$_[1]};
