@@ -149,15 +149,15 @@ function ctest {
     fi
 }
 
-ntests=35
+ntests=42
 declare -a tests[$ntests]
 declare -a result[$ntests]
 ncctests=3
 declare -a cctests[$((100+$ncctests))]
 declare -a ccresult[$((100+$ncctests))]
-tests[1]="print 'hi'"
+tests[1]='print "hi"'
 result[1]='hi';
-tests[2]="for (1,2,3) { print if /\d/ }"
+tests[2]='for (1,2,3) { print if /\d/ }'
 result[2]='123';
 tests[3]='$_ = "xyxyx"; %j=(1,2); s/x/$j{print("z")}/ge; print $_'
 result[3]='zzz2y2y2';
@@ -243,17 +243,12 @@ result[30]='456123E0'
 tests[31]='package MockShell;sub AUTOLOAD{my $p=$AUTOLOAD;$p=~s/.*:://;print(join(" ",$p,@_),";");} package main; MockShell::date();MockShell::who("am","i");MockShell::ls("-l");'
 result[31]='date;who am i;ls -l;'
 # CC entertry/jmpenv_jump/leavetry
-tests[32]='eval{print "1"};eval{die 1};print "2\n";'
+tests[32]='eval{print "1"};eval{die 1};print "2";'
 result[32]='12'
 # C qr test was broken in 5.6 -- needs to load an actual file to test. See test 20.
 # used to error with Can't locate object method "save" via package "U??WVS?-" (perhaps you forgot to load "U??WVS?-"?) at /usr/lib/perl5/5.6.2/i686-linux/B/C.pm line 676.
-# fails with new constant only. still not repro
-tests[33]='package qr; 
-my $var = 1;
-my $qr_with_var = qr/^_?[^\W_0-9]\w*$var/;
-sub qr_called_in_sub { $name =~ $qr_with_var; }
-package main;
-print "ok";'
+# fails with new constant only. still not repro (r-magic probably)
+tests[33]='BEGIN{unshift @INC,("t");} use qr_loaded_module; print "ok"'
 result[33]='ok'
 # init of magic hashes. %ENV has e magic since a0714e2c perl.c  
 # (Steven Schubiger      2006-02-03 17:24:49 +0100 3967) i.e. 5.8.9 but not 5.8.8
@@ -265,7 +260,35 @@ result[35]='ok'
 # HV self-ref
 tests[36]='my ($rv, %hv); %hv = ( key => \$rv ); $rv = \%hv; print "ok";'
 result[36]='ok'
-
+# AV self-ref
+tests[37]='my ($rv, @av); @av = ( \$rv ); $rv = \@av; print "ok";'
+result[37]='ok'
+# constant autoload loop crash test
+tests[38]='for(1 .. 1024) { if (open(my $null_fh,"<","/dev/null")) { seek($null_fh,0,SEEK_SET); close($null_fh); $ok++; } }if ($ok == 1024) { print "ok"; }'
+result[38]='ok'
+# check re::is_regexp, and on 5.12 if being upgraded to SVt_REGEXP
+# => Undefined subroutine &re::is_regexp with B-C-1.19, even with -ure
+usere="`$PERL -e'print (($] < 5.011) ? q(use re;) : q())'`"
+tests[39]='{'$usere'$a=${qr//};$a=2;print ($] < 5.007?1:re::is_regexp(\$a))}'
+result[39]='1'
+# String with a null byte -- used to generate broken .c on 5.6.2 with static pvs
+tests[40]='my $var="this string has a null \\000 byte in it";print "ok";'
+result[40]='ok'
+# Shared scalar, n magic. => Don't know how to handle magic of type \156.
+usethreads="`$PERL -MConfig -e'print ($Config{useithreads} ? q(use threads;) : q())'`"
+#;threads->create(sub{$s="ok"})->join;
+# not yet testing n, only P
+tests[41]=$usethreads'use threads::shared;{my $s="ok";share($s);print $s}'
+result[41]='ok'
+# Shared aggregate, P magic
+tests[42]=$usethreads'use threads::shared;my %h : shared; print "ok"'
+result[42]='ok'
+# Aggregate element, n + p magic
+tests[43]=$usethreads'use threads::shared;my @a : shared; $a[0]="ok"; print $a[0]'
+result[43]='ok'
+# perl #72922 (5.11.4 fails with magic_killbackrefs)
+tests[44]='use Scalar::Util "weaken";my $re1=qr/foo/;my $re2=$re1;weaken($re2);print "ok" if $re3=qr/$re1/;'
+result[44]='ok'
 
 # from here on we test CC specifics only
 
